OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "Migráció folyamatban. Kérlek várj, míg a migráció befejeződik.",
    "Migration started …" : "Migráció elindítva ...",
    "Saved" : "Elmentve",
    "Not saved" : "Nincs mentve",
    "Sending…" : "Küldés...",
    "Email sent" : "Az e-mail elküldve!",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Hiba történt! Kérem töltsön fel egy, ASCII karakterekkel kódolt PEM tanusítványt!",
    "Valid until {date}" : "Érvényes: {date}",
    "Delete" : "Törlés",
    "Local" : "Helyi",
    "Private" : "Privát",
    "Only visible to local users" : "Csak a helyi felhasználók láthatják",
    "Only visible to you" : "Csak te láthatod",
    "Contacts" : "Névjegyek",
    "Visible to local users and to trusted servers" : "Helyi felhasználók és megbízható szerverek láthatják",
    "Public" : "Nyilvános",
    "Will be synced to a global and public address book" : "Globális és nyilvános névjegyek számára lesz szinkronizálva",
    "Verify" : "Ellenőrzés",
    "Verifying …" : "Ellenőrzés...",
    "Unable to change password" : "Nem sikerült megváltoztatni a jelszót",
    "Very weak password" : "Nagyon gyenge jelszó",
    "Weak password" : "Gyenge jelszó",
    "So-so password" : "Nem túl jó jelszó",
    "Good password" : "Jó jelszó",
    "Strong password" : "Erős jelszó",
    "An error occurred while changing your language. Please reload the page and try again." : "Hiba lépett fel nyelvváltás közben. Kérlek töltsd újra az oldalt és próbáld ismét.",
    "An error occurred while changing your locale. Please reload the page and try again." : "Hiba a hely váltása közben. Kérlek töltsd újra az oldalt és próbáld meg ismét.",
    "Select a profile picture" : "Válasszon profilképet!",
    "Week starts on {fdow}" : "Hét kezdete {fdow}",
    "Groups" : "Csoportok",
    "Group list is empty" : "Csoport lista üres",
    "Unable to retrieve the group list" : "Csoportlista betöltése sikertelen",
    "{actor} added you to group {group}" : "{actor} hozzá lett adva a {group} csoporthoz",
    "You added {user} to group {group}" : "Hozzáadta {user} felhasználót a(z) {group} csoporthoz",
    "{actor} added {user} to group {group}" : "{actor} hozzáadta {user} felhasználót a(z) {group} csoporthoz",
    "An administrator added you to group {group}" : "A rendszergazda hozzáadta a(z) {group} csoporthoz",
    "An administrator added {user} to group {group}" : "A rendszergazda hozzáadta {user} felhasználót a(z) {group} csoporthoz",
    "{actor} removed you from group {group}" : "{actor} el lett távolítva a(z) {group} csoportból",
    "You removed {user} from group {group}" : "Eltávolította {user} felhasználót a(z) {group} csoportból",
    "{actor} removed {user} from group {group}" : "{actor} eltávolította {user} felhasználót a(z) {group} csoportból",
    "An administrator removed you from group {group}" : "A rendszergazda eltávolította a(z) {group} csoportból",
    "An administrator removed {user} from group {group}" : "A rendszergazda eltávolította {user} felhasználót a(z) {group} csoportból",
    "Your <strong>group memberships</strong> were modified" : "A <strong>csoporttagsága</strong> megváltozott",
    "{actor} changed your password" : "{actor} módosította a jelszavát",
    "You changed your password" : "Módosította a jelszavát",
    "Your password was reset by an administrator" : "A jelszavát visszaállította egy rendszergazda",
    "{actor} changed your email address" : "{actor} megváltoztatta az e-mail címét",
    "You changed your email address" : "Megváltoztatta az e-mail címét",
    "Your email address was changed by an administrator" : "Az e-mail címét megváltoztatta egy rendszergazda",
    "You created app password \"{token}\"" : "Létrehozta a(z) „{token}” alkalmazásjelszót",
    "You deleted app password \"{token}\"" : "Törölte a(z) „{token}” alkalmazásjelszót",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Átnevezted a(z) „{token}” alkalmazásjelszót erre: „{newToken}”",
    "You granted filesystem access to app password \"{token}\"" : "Fájlrendszer-hozzáférést adott a(z) „{token}” alkalmazásjelszónak",
    "You revoked filesystem access from app password \"{token}\"" : "Visszavonta a(z) „{token}” alkalmazásjelszó fájlrendszer-hozzáférését",
    "Security" : "Biztonság",
    "You successfully logged in using two-factor authentication (%1$s)" : "Sikeresen bejelentkezett kétfaktoros hitelesítés használatával (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Egy kétfaktoros bejelentkezési kísérlet sikertelen volt (%1$s)",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "A <strong>jelszavad </strong> vagy <strong>email címed</strong> megváltozott",
    "Couldn't remove app." : "Az alkalmazást nem sikerült eltávolítani.",
    "Couldn't update app." : "Az alkalmazás frissítése nem sikerült.",
    "Wrong password" : "Hibás jelszó",
    "No user supplied" : "Nincs megadva felhasználó",
    "Authentication error" : "Azonosítási hiba",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Kérjük, adjon meg egy rendszergazdai visszaállító jelszót; különben, az összes felhasználó adata eltűnik.",
    "Wrong admin recovery password. Please check the password and try again." : "Hibás rendszergazda helyreállítási jelszó. Ellenőrizze a jelszót és próbálja újra!",
    "Backend doesn't support password change, but the user's encryption key was updated." : "A háttérszolgáltatás nem támogatja a jelszómódosítást, de a titkosítási kulcs frissítve lett.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "alkalmazások telepítése és frissítése az alkalmazás tárból vagy Szövetséges Felhő Megosztásból",
    "Federated Cloud Sharing" : "Megosztás Egyesített Felhőben",
    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL elavult %1$s verziót (%2$s) használ. Kérlek, frissítsd az operációs rendszert, vagy egyes funkciók (mint például a %3$s) megbízhatatlanul fognak működni.",
    "Invalid SMTP password." : "Érvénytelen SMTP jelszó",
    "Email setting test" : "E-mail beállítás tesztelése",
    "Well done, %s!" : "Szép munka,  %s!",
    "If you received this email, the email configuration seems to be correct." : "Ha ezt a levelet látod, a beállításaid megfelelőnek tűnnek.",
    "Email could not be sent. Check your mail server log" : "E-mail nem elküldhető. Ellenőrizd a mailszerver naplójában",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Hiba történt az e-mail küldésekor. Kérlek ellenőrizd a beállításokat! (Hiba: %s)",
    "You need to set your user email before being able to send test emails." : "Előbb meg kell adnia az e-mail címét, mielőtt tesztelni tudná az e-mail küldést.",
    "Invalid mail address" : "Érvénytelen e-mail cím",
    "Settings saved" : "Beállítások elmentve",
    "Unable to change full name" : "Nem sikerült megváltoztatni a teljes nevét",
    "Unable to change email address" : "Nem lehet megváltoztatni az e-mail címet",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "A twitter fiók megerősítésére tweeteld ki az alábbit. (Kérünk pontosan így, sortörések nélkül tweeteld)",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "A weboldalad ellenőrzése érdekében helyezd el a következő tartalmat a  '.well-known/CloudIdVerificationCode.txt'-ba. (figyelj arra, hogy az egész szöveg egy sorban legyen):",
    "%1$s changed your password on %2$s." : "%1$smegváltoztatta a jelszavadat%2$s-on.",
    "Your password on %s was changed." : "A jelszavad %s-on megváltozott.",
    "Your password on %s was reset by an administrator." : "A jelszavad %s-on visszaállította egy rendszergazda.",
    "Password for %1$s changed on %2$s" : "%1$s jelszava megváltozott %2$s-on",
    "Password changed for %s" : "%s jelszava módosítva",
    "If you did not request this, please contact an administrator." : "Ha ezt nem te kérted, lépj kapcsolatba egy rendszergazdával.",
    "Your email address on %s was changed." : "Az e-mail címed megváltozott %s-on.",
    "Your email address on %s was changed by an administrator." : "Az e-mail címedet %s-on megváltoztatta egy rendszergazda.",
    "Email address for %1$s changed on %2$s" : "%1$s e-mail címe megváltozott%2$s-on",
    "Email address changed for %s" : "%s e-mail címe módosítva",
    "The new email address is %s" : "Az új e-mail cím %s",
    "Your %s account was created" : "%s fiók létrehozva",
    "Welcome aboard" : "Üdv a fedélzeten",
    "Welcome aboard %s" : "Üdv a fedélzeten %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "Üdv a(z) %s hozzáférésedben. Hozzáadhatod, védheted, megoszthatod adataidat.",
    "Your username is: %s" : "A felhasználóneved: %s",
    "Set your password" : "Állítsd be a jelszabad",
    "Go to %s" : "Menj ide: %s",
    "Install Client" : "Kliens telepítés",
    "Logged in user must be a subadmin" : "Nem rendszergazda felhasználóként kell bejelentkezzen",
    "Create" : "Létrehozás",
    "Change" : "Módosít",
    "Share" : "Megosztás",
    "Unlimited" : "Korlátlan",
    "Verifying" : "Ellenőrzés",
    "Two-factor authentication can be enforced for all\tusers and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "A kétfaktoros hitelesítés minden felhasználóra vagy bizonyos csoportokra követelhető meg. Ha a kétfaktoros hitelesítés nincs nekik beállítva, nem fognak tudni belépni a rendszerbe.",
    "Enforce two-factor authentication" : "Kétfaktoros hitelesítés megkövetelése",
    "Limit to groups" : "Csoportokra korlátozás",
    "Enforcement of two-factor authentication can be set for certain groups only." : "A kétfaktoros hitelesítés megkövetelése csak bizonyos csoportokra állítható be.",
    "Two-factor authentication is enforced for all\tmembers of the following groups." : "A kétfaktoros hitelesítés meg van követelve a következő csoport minden tagjára.",
    "Enforced groups" : "Kötelező csoportok",
    "Two-factor authentication is not enforced for\tmembers of the following groups." : "A kétfaktoros hitelesítés meg van nincs megkövetelve a következő csoport tagjaira.",
    "Excluded groups" : "Kizárt csoportok",
    "Save changes" : "Változások mentése",
    "Supported" : "Támogatott",
    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "A hivatalos alkalmazásokat a közösség fejleszti. Ezek adják a központi funkcionalitásokat és éles rendszerekben használhatóak.",
    "Official" : "Hivatalos",
    "by" : "által",
    "Update to {version}" : "Frissítés erre: {version}",
    "Remove" : "Eltávolítás",
    "Disable" : "Letiltás",
    "All" : "Mind",
    "Limit app usage to groups" : "Alkalmazás asználatának korlátozása a következő csoportokra",
    "No results" : "Nincsenek eredmények",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ennek az alkalmazásnak nincs minimum szükséges Nextcloud verziója megadva. Ez hiba lesz a jövőben.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ennek az alkalmazásnak nincs maximum szükséges Nextcloud verziója megadva. Ez hiba lesz a jövőben.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ezt az alkalmazást nem lehet telepíteni, mert a következő függőségek hiányoznak:",
    "View in store" : "Megtekintés a tárban",
    "Visit website" : "Weboldal meglátogatása",
    "Report a bug" : "Hiba bejelentése",
    "User documentation" : "Felhasználói dokumentáció",
    "Admin documentation" : "Rendszergazdai dokumentáció",
    "Developer documentation" : "Fejlesztői dokumentáció",
    "Update to {update}" : "Frissítés erre: {update}",
    "Results from other categories" : "Eredmények más kategóriákból",
    "No apps found for your version" : "Nem található alkalmazás a verziód számára",
    "Disable all" : "Összes tiltása",
    "Enable all" : "Mind engedélyezése",
    "Download and enable" : "Letöltés és engedélyezés",
    "Enable" : "Engedélyezés",
    "The app will be downloaded from the app store" : "Az alkalmazás letöltésre kerül az alkalmazástárból",
    "Device settings" : "Eszköz beállítások",
    "Allow filesystem access" : "Fájlrendszer hozzáférés engedélyezése",
    "Rename" : "Átnevez",
    "Revoke" : "Visszavonás",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome for Android",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "Nextcloud iOS app" : "Nextcloud iOS alkalmazás",
    "Nextcloud Android app" : "Nextcloud Android alkalmazás",
    "Nextcloud Talk for iOS" : "Nextcloud Talk iOS-re",
    "Nextcloud Talk for Android" : "Nextcloud Talk Android-ra",
    "Sync client - {os}" : "Szinkron kliens - {os}",
    "This session" : "Ez a munkamenet",
    "Device" : "Eszköz",
    "Last activity" : "Utolsó tevékenység",
    "Devices & sessions" : "Eszközök és munkamenetek",
    "Web, desktop and mobile clients currently logged in to your account." : "A fiókodba jelenleg bejelentkezett web, asztali és mobil kliensek.",
    "Error while creating device token" : "Hiba az eszköztoken létrehozása közben",
    "Error while deleting the token" : "Hiba az eszköztoken törlésénél",
    "App name" : "Alkalmazás név",
    "Create new app password" : "Új alkalmazás jelszó létrehozása",
    "Use the credentials below to configure your app or device." : "Használja a lenti hitelesítő adatokat hogy beállítsa az alkalmazását vagy eszközét.",
    "For security reasons this password will only be shown once." : "Biztonsági okokból ez a jelszó csak egyszer jelenik meg.",
    "Username" : "Felhasználónév",
    "Password" : "Jelszó",
    "Done" : "Kész",
    "Copied!" : "Másolva!",
    "Copy" : "Másol",
    "You do not have permissions to see the details of this user" : "Nincs jogosultságod megnézni ennek a felhasználónak a részleteit.",
    "The backend does not support changing the display name" : "A feldolgozó nem támogatja a megjelenítő nevének megváltoztatását",
    "New password" : "Az új jelszó",
    "Add user in group" : "Felhasználó hozzáadása a csoporthoz",
    "Set user as admin for" : "Felhasználó beállítása adminként erre:",
    "Select user quota" : "Válassz felhasználói kvótát",
    "No language set" : "Nyelv nincs beállítva",
    "Never" : "Soha",
    "Delete user" : "Felhasználó törlése",
    "Disable user" : "Felhasználó tiltása",
    "Enable user" : "Felhasználó engedélyezése",
    "Resend welcome email" : "Üdvözlő üzenet ismételt küldése",
    "{size} used" : "{size} felhasználva",
    "Welcome mail sent!" : "Üdvöző üzenet elküldve!",
    "Display name" : "Név megjelenítés",
    "Email" : "E-mail",
    "Group admin for" : "Csoport Rendszergazda itt",
    "Quota" : "Kvóta",
    "Language" : "Nyelv",
    "Storage location" : "A háttértár helye",
    "User backend" : "Felhasználói háttér",
    "Last login" : "Utolsó bejelentkezés",
    "Default language" : "Alapértelmezett nyelv",
    "Add a new user" : "Új felhasználó felvétele",
    "No users in here" : "Nincs ilyen felhasználó",
    "Default quota" : "Alapértelmezett kvóta",
    "Common languages" : "Alapvető nyelvek",
    "All languages" : "Minden nyelv",
    "Password change is disabled because the master key is disabled" : "A jelszó változtatása tiltva van mert a mester kulcs tiltva van",
    "Your apps" : "Alkalmazásaid",
    "Active apps" : "Aktív alkalmazások",
    "Disabled apps" : "Letiltott alkalmazások",
    "Updates" : "Feltöltések",
    "App bundles" : "Alkalmazás csomagok",
    "{license}-licensed" : "{license}-licencelt",
    "New user" : "Új felhasználó",
    "Default quota:" : "Alapértelmezett kvóta:",
    "Select default quota" : "Válassz alapértelmezett kvótát",
    "Show Languages" : "Nyelvek mutatása",
    "Show last login" : "Utolsó bejelentkezés megjelenítése",
    "Show user backend" : "Felhasználói háttér mutatása",
    "Show storage path" : "Tároló útvonal mutatása",
    "Remove group" : "Csoport törlése",
    "Admins" : "Rendszergazdák",
    "Disabled users" : "Letiltott felhasználók",
    "Everyone" : "Mindenki",
    "Add group" : "csoport hozzáadása",
    "You are about to remove the group {group}. The users will NOT be deleted." : "A {group} csoportot fodja törölni. A felhasználó NEM fog törlődni.",
    "Please confirm the group removal " : "Kérem erősítse meg a csoport törlését",
    "An error occured during the request. Unable to proceed." : "Hiba lépett fel a kérés közben. Nem lehet végrehajtani.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Ez az alkalmazás engedélyezve van, de frissíteni kell. A frissítő oldalra irányítjuk 5 másodpercen belül.",
    "App update" : "Alkalmazás frissítése",
    "Error: This app can not be enabled because it makes the server unstable" : "Hiba: az alkalmazás nem nem engedélyezhető, mert instabillá tenné a szervert",
    "SSL Root Certificates" : "SSL Root tanusítványok",
    "Common Name" : "Általános Név",
    "Valid until" : "Érvényes",
    "Issued By" : "Kiadta",
    "Valid until %s" : "Érvényes: %s",
    "Import root certificate" : "Gyökértanúsítvány importálása",
    "Administrator documentation" : "Rendszergazdai dokumentáció",
    "Documentation" : "Dokumentáció",
    "Forum" : "Fórum",
    "None" : "Egyik sem",
    "Login" : "Login",
    "Plain" : "Egyszerű",
    "NT LAN Manager" : "NT LAN Manager",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "E-mail szerver",
    "Open documentation" : "Dokumentáció megnyitása",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Fontos, hogy a levelezés be legyen állítva a szerveren például a jelszóvisszaállítások és értesítések miatt.",
    "Send mode" : "Küldési mód",
    "Encryption" : "Titkosítás",
    "Sendmail mode" : "Sendmail mód",
    "From address" : "A feladó címe",
    "mail" : "levél",
    "Authentication method" : "A felhasználóazonosítás módszere",
    "Authentication required" : "Felhasználóazonosítás szükséges",
    "Server address" : "A szerver címe",
    "Port" : "Port",
    "Credentials" : "Azonosítók",
    "SMTP Username" : "SMTP felhasználónév",
    "SMTP Password" : "SMTP jelszó",
    "Test email settings" : "Az e-mail beállítások ellenőrzése",
    "Send email" : "E-mail küldése",
    "Security & setup warnings" : "Biztonsági és telepítési figyelmeztetések",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "A telepítésed biztonságához és megfelelő teljesítményéhez fontos, hogy minden beállítás helyes legyen. Ennek érdekében segítünk pár automatikus ellenőrzéssel. Kérlek tekintsd meg a kapcsolódó dokumentációt a további információért.",
    "All checks passed." : "Minden ellenőrzés sikeres.",
    "There are some errors regarding your setup." : "Probléma lépett fel a beállításaival kapcsolatban.",
    "There are some warnings regarding your setup." : "Figyelmeztetés jött fel a beállításaival kapcsolatban.",
    "Checking for system and security issues." : "Rendszer és biztonsági dolgok ellenőrzése.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "Kérlek ismét ellenőrizd a <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">telepítési dokumentációt ↗</a>, és keress hibákat és figyelmeztetéseket a <a href=\"%2$s\">naplóban</a>.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "Ellenőrizze a Nextcloud biztonságát <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\"> a biztonsági ellenőrzőnkkel ↗</a>.",
    "Version" : "Verzió",
    "Two-Factor Authentication" : "Kétfaktoros hitelesítés",
    "Server-side encryption" : "Szerver-oldali titkosítás",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "A szerveroldali titkosítás segítségével a tárolt fájlok titkosítva kerülnek tárolásra a szerveren. Ez korlátozásokkal jár, például teljesítmény csökkenést okoz, így csak akkor kapcsold be, ha szükséges.",
    "Enable server-side encryption" : "Szerver-oldali titkosítás engedélyezése",
    "Please read carefully before activating server-side encryption: " : "Kérjük, ezt olvasd el figyelmesen mielőtt engedélyezed a szerveroldali titkosítást:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Ha egyszer engedélyezve lett a titkosítás, akkor onnantól kezdve a szerveren az összes fájl titkosításra kerül, melyet később csak akkor lehet visszafordítani, ha azt az aktív titkosítási modul támogatja és minden elő-követelmény (például helyreállító kulcs) teljesül.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "A titkosítás önmagában nem garantálja a rendszer biztonságát. Kérem olvassa el a dokumentációt, hogy további információkat szerezzen a titkosítási alkalmazás működéséről, és a támogatott lehetőségekről.",
    "Be aware that encryption always increases the file size." : "Ügyeljen arra, hogy a titkosítás mindig megnöveli a fájl méretét!",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Mindig jó ötlet rendszeres biztonsági mentést készíteni az adatokról. Titkosítás esetén a titkosító kulcsok biztonsági mentését elkülönítve tárolja az adatoktól!",
    "This is the final warning: Do you really want to enable encryption?" : "Ez az utolsó figyelmeztetés: Biztosan szeretnéd engedélyezni a titkosítást?",
    "Enable encryption" : "Titkosítás engedélyezése",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Nincs titkosítási modul betöltve, kérjük engedélyezd a titkosítási modult az alkalmazások menüben.",
    "Select default encryption module:" : "Alapértelmezett titkosítási modul:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Migrálni kell a titkosítási kulcsokat a régi titkosításból (ownCloud <= 8.0) egy újba. Kérjük, engedélyezd az „Alapértelmezett titkosítási modul”-t és futtasd ezt: occ encryption:migrate",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Migrálni kell a titkosítási kulcsokat a régi titkosításból (ownCloud <= 8.0) egy újba.",
    "Start migration" : "Migrálás indítása",
    "Background jobs" : "Háttérfeladatok",
    "Last job ran %s." : "Utolsó futás: %s.",
    "Last job execution ran %s. Something seems wrong." : "Utolsó futás:%s. Valami nincs rendben.",
    "Background job didn’t run yet!" : "Háttérfeladat még nem futott le!",
    "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "Az optimális teljesítményhez fontos, hogy a háttérfeladatok megfelelően legyenek beállítva. Nagyobb telepítésekhez a 'Cron' javasolt. Kérlek nézd meg a dokumentációt a részletekért.",
    "Execute one task with each page loaded" : "Egy-egy feladat végrehajtása minden alkalommal, amikor egy weboldalt letöltenek",
    "The cron.php needs to be executed by the system user \"%s\"." : "A cron.php-t ennek a rendszer felhasználónak kell végrehajtania: \"%s\".",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Ennek futtatásához PHP POSIX kiterjesztés szükséges. Nézd meg a {linkstart}PHP dokumentációt{linkend} a részletekért.",
    "Sharing" : "Megosztás",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Rendszergazdaként finomhangolhatod a megosztás viselkedését. Kérlek nézd meg a dokumentációt a részletekért.",
    "Allow apps to use the Share API" : "Lehetővé teszi, hogy a programmodulok is használhassák a megosztást",
    "Allow users to share via link" : "Engedjük meg a fájlok hivatkozással történő megosztását",
    "Allow public uploads" : "Nyilvános feltöltés engedélyezése",
    "Always ask for a password" : "Mindig kérdezze meg a jelszót",
    "Enforce password protection" : "Legyen kötelező a linkek jelszóval való védelme",
    "Set default expiration date" : "Alapértelmezett lejárati idő beállítása",
    "Expire after " : "A lejárat legyen",
    "days" : "nap",
    "Enforce expiration date" : "A beállított lejárati idő legyen kötelezően érvényes",
    "Allow resharing" : "A megosztás továbbadásának engedélyezése",
    "Allow sharing with groups" : "Megosztás engedélyezése a csoportokkal",
    "Restrict users to only share with users in their groups" : "A csoporttagok csak a saját csoportjukon belül oszthassanak meg anyagokat",
    "Exclude groups from sharing" : "Csoportok megosztási jogának tiltása",
    "These groups will still be able to receive shares, but not to initiate them." : "E csoportok tagjaival meg lehet osztani anyagokat, de ők nem hozhatnak létre megosztást.",
    "Allow username autocompletion in share dialog. If this is disabled the full username or email address needs to be entered." : "Felhasználónevek automatikus kiegészítésének engedélyezése a megosztási ablakban. Ha ki van kapcsolva, teljes felhasználóneveket vagy e-mail címeket kell begépelni.",
    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "Nyilatkozat szövegének megjelenítése a nyilvános feltöltési oldalon. (Csak akkor jelenik meg, ha fájl lista rejtett.)",
    "This text will be shown on the public link upload page when the file list is hidden." : "Ez a szöveg jelenik meg a nyilvános feltöltési oldalon, amikor a fájl lista el van rejtve.",
    "Default share permissions" : "Alapértelmezett megosztási beállítások",
    "Personal" : "Személyes",
    "Administration" : "Adminisztráció",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Fejleszti a {communityopen}Nextcloud közösség{linkclose}, a {githubopen}forráskódra{linkclose} az {licenseopen}AGPL{linkclose} licenc vonatkozik.",
    "Like our Facebook page" : "Lájkold a Facebook oldalunkat",
    "Follow us on Twitter" : "Kövess Twitteren",
    "Follow us on Mastodon" : "Kövess mindet a Mastodon-on",
    "Check out our blog" : "Nézd meg a blogunkat",
    "Subscribe to our newsletter" : "Iratkozz fel a hírlevelünkre",
    "Profile picture" : "Profilkép",
    "Upload new" : "Új feltöltése",
    "Select from Files" : "Kiválasztás fájlokból",
    "Remove image" : "Kép eltávolítása",
    "png or jpg, max. 20 MB" : "png vagy jpg, max. 20 MB",
    "Picture provided by original account" : "Az eredeti fiók által biztosított kép.",
    "Cancel" : "Mégsem",
    "Choose as profile picture" : "Kiválasztás profil képként",
    "Details" : "Részletek",
    "You are a member of the following groups:" : "Tagja vagy a következő csoport(ok)nak:",
    "You are using <strong>%s</strong>" : "Jelenleg használt <strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Jelenleg használt <strong>%1$s</strong> a <strong>%2$s</strong>-ből (<strong>%3$s %%</strong>)",
    "Full name" : "Teljes név",
    "No display name set" : "Nincs megjelenítési név beállítva",
    "Your email address" : "Az Ön e-mail címe",
    "No email address set" : "Nincs e-mail cím beállítva",
    "For password reset and notifications" : "Jelszó-visszaállításhoz és értesítésekhez",
    "Phone number" : "Telefonszám",
    "Your phone number" : "Telefonszáma",
    "Address" : "Cím",
    "Your postal address" : "A postai címe",
    "Website" : "Weboldal",
    "Link https://…" : "https:// hivatkozás…",
    "Twitter" : "Twitter",
    "Twitter handle @…" : "Twitter azonosító @…",
    "Help translate" : "Segítsen a fordításban",
    "Locale" : "Területi beállítás",
    "Current password" : "Jelenlegi jelszó",
    "Change password" : "Jelszó megváltoztatása",
    "Disconnect" : "Szétkapcsolás",
    "Not supported!" : "Nem támogatott.",
    "Press ⌘-C to copy." : "A másoláshoz nyomj ⌘-C-t.",
    "Press Ctrl-C to copy." : "A másoláshoz nyomj Ctrl-C-t.",
    "Error while loading browser sessions and device tokens" : "Hiba a böngésző munkamenet és az eszköz tokenek betöltése közben.",
    "Store credentials" : "Azonosítók eltárolása",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "a cron.php a webcron szolgáltatásban van regisztrálva 15 percenkénti meghívásra HTTP-n keresztül.",
    "Use system cron service to call the cron.php file every 15 minutes." : "A rendszer cron szolgáltatásának használata a cron.php meghívására 15 percenként.",
    "Follow us on Google+" : "Kövess Google+ -on"
},
"nplurals=2; plural=(n != 1);");
